/****************************************************************************
** Meta object code from reading C++ file 'dquickarrowboxpath_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../src/private/dquickarrowboxpath_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickarrowboxpath_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3Dtk5Quick18DQuickArrowBoxPathE_t {};
} // unnamed namespace

template <> constexpr inline auto Dtk::Quick::DQuickArrowBoxPath::qt_create_metaobjectdata<qt_meta_tag_ZN3Dtk5Quick18DQuickArrowBoxPathE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Dtk::Quick::DQuickArrowBoxPath",
        "QML.Element",
        "ArrowBoxPath",
        "widthChanged",
        "",
        "heightChanged",
        "arrowDirectionChanged",
        "arrowXChanged",
        "arrowYChanged",
        "arrowWidthChanged",
        "arrowHeightChanged",
        "roundedRadiusChanged",
        "spreadChanged",
        "arrowDirection",
        "Direction",
        "width",
        "height",
        "arrowX",
        "arrowY",
        "arrowWidth",
        "arrowHeight",
        "roundedRadius",
        "spread",
        "Up",
        "Down",
        "Left",
        "Right"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'arrowDirectionChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'arrowXChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'arrowYChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'arrowWidthChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'arrowHeightChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'roundedRadiusChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'spreadChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'arrowDirection'
        QtMocHelpers::PropertyData<enum Direction>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'width'
        QtMocHelpers::PropertyData<qreal>(15, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'height'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'arrowX'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'arrowY'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'arrowWidth'
        QtMocHelpers::PropertyData<qreal>(19, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'arrowHeight'
        QtMocHelpers::PropertyData<qreal>(20, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'roundedRadius'
        QtMocHelpers::PropertyData<qreal>(21, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'spread'
        QtMocHelpers::PropertyData<qreal>(22, QMetaType::QReal, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Direction'
        QtMocHelpers::EnumData<enum Direction>(14, 14, QMC::EnumFlags{}).add({
            {   23, Direction::Up },
            {   24, Direction::Down },
            {   25, Direction::Left },
            {   26, Direction::Right },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<DQuickArrowBoxPath, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Dtk::Quick::DQuickArrowBoxPath::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickCurve::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickArrowBoxPathE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickArrowBoxPathE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3Dtk5Quick18DQuickArrowBoxPathE_t>.metaTypes,
    nullptr
} };

void Dtk::Quick::DQuickArrowBoxPath::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickArrowBoxPath *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->widthChanged(); break;
        case 1: _t->heightChanged(); break;
        case 2: _t->arrowDirectionChanged(); break;
        case 3: _t->arrowXChanged(); break;
        case 4: _t->arrowYChanged(); break;
        case 5: _t->arrowWidthChanged(); break;
        case 6: _t->arrowHeightChanged(); break;
        case 7: _t->roundedRadiusChanged(); break;
        case 8: _t->spreadChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::widthChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::heightChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::arrowDirectionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::arrowXChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::arrowYChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::arrowWidthChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::arrowHeightChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::roundedRadiusChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickArrowBoxPath::*)()>(_a, &DQuickArrowBoxPath::spreadChanged, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<enum Direction*>(_v) = _t->arrowDirection(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->width(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->height(); break;
        case 3: *reinterpret_cast<qreal*>(_v) = _t->arrowX(); break;
        case 4: *reinterpret_cast<qreal*>(_v) = _t->arrowY(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->arrowWidth(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->arrowHeight(); break;
        case 7: *reinterpret_cast<qreal*>(_v) = _t->roundedRadius(); break;
        case 8: *reinterpret_cast<qreal*>(_v) = _t->spread(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setArrowDirection(*reinterpret_cast<enum Direction*>(_v)); break;
        case 1: _t->setWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 2: _t->setHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 3: _t->setArrowX(*reinterpret_cast<qreal*>(_v)); break;
        case 4: _t->setArrowY(*reinterpret_cast<qreal*>(_v)); break;
        case 5: _t->setArrowWidth(*reinterpret_cast<qreal*>(_v)); break;
        case 6: _t->setArrowHeight(*reinterpret_cast<qreal*>(_v)); break;
        case 7: _t->setRoundedRadius(*reinterpret_cast<qreal*>(_v)); break;
        case 8: _t->setSpread(*reinterpret_cast<qreal*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Dtk::Quick::DQuickArrowBoxPath::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickArrowBoxPath::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3Dtk5Quick18DQuickArrowBoxPathE_t>.strings))
        return static_cast<void*>(this);
    return QQuickCurve::qt_metacast(_clname);
}

int Dtk::Quick::DQuickArrowBoxPath::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickCurve::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickArrowBoxPath::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickArrowBoxPath::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickArrowBoxPath::arrowDirectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickArrowBoxPath::arrowXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickArrowBoxPath::arrowYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickArrowBoxPath::arrowWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Dtk::Quick::DQuickArrowBoxPath::arrowHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Dtk::Quick::DQuickArrowBoxPath::roundedRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Dtk::Quick::DQuickArrowBoxPath::spreadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
