/****************************************************************************
** Meta object code from reading C++ file 'dquickglow_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../src/private/dquickglow_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dquickglow_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Dtk__Quick__DQuickGlow_t {
    QByteArrayData data[14];
    char stringdata0[179];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Dtk__Quick__DQuickGlow_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Dtk__Quick__DQuickGlow_t qt_meta_stringdata_Dtk__Quick__DQuickGlow = {
    {
QT_MOC_LITERAL(0, 0, 22), // "Dtk::Quick::DQuickGlow"
QT_MOC_LITERAL(1, 23, 17), // "glowRadiusChanged"
QT_MOC_LITERAL(2, 41, 0), // ""
QT_MOC_LITERAL(3, 42, 12), // "colorChanged"
QT_MOC_LITERAL(4, 55, 13), // "spreadChanged"
QT_MOC_LITERAL(5, 69, 20), // "relativeSizeXChanged"
QT_MOC_LITERAL(6, 90, 19), // "relativeSizeYChangd"
QT_MOC_LITERAL(7, 110, 11), // "fillChanged"
QT_MOC_LITERAL(8, 122, 10), // "glowRadius"
QT_MOC_LITERAL(9, 133, 5), // "color"
QT_MOC_LITERAL(10, 139, 6), // "spread"
QT_MOC_LITERAL(11, 146, 13), // "relativeSizeX"
QT_MOC_LITERAL(12, 160, 13), // "relativeSizeY"
QT_MOC_LITERAL(13, 174, 4) // "fill"

    },
    "Dtk::Quick::DQuickGlow\0glowRadiusChanged\0"
    "\0colorChanged\0spreadChanged\0"
    "relativeSizeXChanged\0relativeSizeYChangd\0"
    "fillChanged\0glowRadius\0color\0spread\0"
    "relativeSizeX\0relativeSizeY\0fill"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Dtk__Quick__DQuickGlow[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       6,   50, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       6,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   44,    2, 0x06 /* Public */,
       3,    0,   45,    2, 0x06 /* Public */,
       4,    0,   46,    2, 0x06 /* Public */,
       5,    0,   47,    2, 0x06 /* Public */,
       6,    0,   48,    2, 0x06 /* Public */,
       7,    0,   49,    2, 0x06 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       8, QMetaType::QReal, 0x00495103,
       9, QMetaType::QColor, 0x00495103,
      10, QMetaType::QReal, 0x00495103,
      11, QMetaType::QReal, 0x00495103,
      12, QMetaType::QReal, 0x00495103,
      13, QMetaType::Bool, 0x00495103,

 // properties: notify_signal_id
       0,
       1,
       2,
       3,
       4,
       5,

       0        // eod
};

void Dtk::Quick::DQuickGlow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<DQuickGlow *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->glowRadiusChanged(); break;
        case 1: _t->colorChanged(); break;
        case 2: _t->spreadChanged(); break;
        case 3: _t->relativeSizeXChanged(); break;
        case 4: _t->relativeSizeYChangd(); break;
        case 5: _t->fillChanged(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (DQuickGlow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickGlow::glowRadiusChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (DQuickGlow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickGlow::colorChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (DQuickGlow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickGlow::spreadChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (DQuickGlow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickGlow::relativeSizeXChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (DQuickGlow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickGlow::relativeSizeYChangd)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (DQuickGlow::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&DQuickGlow::fillChanged)) {
                *result = 5;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<DQuickGlow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->glowRadius(); break;
        case 1: *reinterpret_cast< QColor*>(_v) = _t->color(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->spread(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->relativeSizeX(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->relativeSizeY(); break;
        case 5: *reinterpret_cast< bool*>(_v) = _t->fill(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<DQuickGlow *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setGlowRadius(*reinterpret_cast< qreal*>(_v)); break;
        case 1: _t->setColor(*reinterpret_cast< QColor*>(_v)); break;
        case 2: _t->setSpread(*reinterpret_cast< qreal*>(_v)); break;
        case 3: _t->setRelativeSizeX(*reinterpret_cast< qreal*>(_v)); break;
        case 4: _t->setRelativeSizeY(*reinterpret_cast< qreal*>(_v)); break;
        case 5: _t->setFill(*reinterpret_cast< bool*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
    (void)_a;
}

QT_INIT_METAOBJECT const QMetaObject Dtk::Quick::DQuickGlow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_Dtk__Quick__DQuickGlow.data,
    qt_meta_data_Dtk__Quick__DQuickGlow,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Dtk::Quick::DQuickGlow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Dtk::Quick::DQuickGlow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Dtk__Quick__DQuickGlow.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Dtk::Quick::DQuickGlow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Dtk::Quick::DQuickGlow::glowRadiusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Dtk::Quick::DQuickGlow::colorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Dtk::Quick::DQuickGlow::spreadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Dtk::Quick::DQuickGlow::relativeSizeXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Dtk::Quick::DQuickGlow::relativeSizeYChangd()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Dtk::Quick::DQuickGlow::fillChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
